#
# spec file for package ardour
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dirbase ardour8
Name:           ardour
Version:        8.11.0
Release:        1.1
Summary:        Multichannel Digital Audio Workstation
# Legal: Ardour is a mix of GPL-2.0-or-later, [L]GPL-3.0-or-later and a couple copyleft
#  licensed files (BSD, WTFPL). Use GPL-3.0-only for the compiled package.
License:        GPL-3.0-only
URL:            https://ardour.org/
Source0:        https://community.ardour.org/download/release/604#/Ardour-%{version}.tar.bz2
Source99:       ardour-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel >= 1.68.0
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  graphviz
BuildRequires:  hicolor-icon-theme
BuildRequires:  itstool > 2.0.0
BuildRequires:  jack-devel
BuildRequires:  libcppunit-devel
BuildRequires:  libhidapi-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  readline-devel
BuildRequires:  rubberband-vamp
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(atkmm-1.6) >= 2.22.6
BuildRequires:  pkgconfig(aubio) >= 0.3.2
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(cairomm-1.0) >= 1.10.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fftw3) >= 3.3.1
BuildRequires:  pkgconfig(flac) >= 1.2.1
BuildRequires:  pkgconfig(fluidsynth) >= 1.1.6
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(giomm-2.4) >= 2.32.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.32.0
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.24.18
BuildRequires:  pkgconfig(gtkmm-2.4) >= 2.24.2
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libart-2.0) >= 2.3.21
BuildRequires:  pkgconfig(libcurl) >= 7.25.0
BuildRequires:  pkgconfig(libexslt)
BuildRequires:  pkgconfig(liblo) >= 0.26
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libwebsockets) >= 2.0.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(lilv-0)
BuildRequires:  pkgconfig(lrdf)
BuildRequires:  pkgconfig(ltc)
BuildRequires:  pkgconfig(lv2) >= 1.2.0
BuildRequires:  pkgconfig(ogg) >= 1.3.0
BuildRequires:  pkgconfig(pangomm-1.4) >= 2.28.4
BuildRequires:  pkgconfig(raptor2) >= 2.0.6
BuildRequires:  pkgconfig(rasqal) >= 0.9.28
BuildRequires:  pkgconfig(redland) >= 1.0.15
BuildRequires:  pkgconfig(rubberband)
BuildRequires:  pkgconfig(samplerate) >= 0.1.8
BuildRequires:  pkgconfig(serd-0)
BuildRequires:  pkgconfig(sigc++-2.0) >= 2.2.10
BuildRequires:  pkgconfig(sndfile) >= 1.0.18
BuildRequires:  pkgconfig(sord-0)
BuildRequires:  pkgconfig(soundtouch) >= 1.8.0
BuildRequires:  pkgconfig(sratom-0)
BuildRequires:  pkgconfig(suil-0)
BuildRequires:  pkgconfig(taglib) >= 1.9.1
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(vamp)
BuildRequires:  pkgconfig(vorbis) >= 1.3.2
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
Requires:       graphviz
Requires:       lv2
%requires_ge    liblilv-0-0
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
Recommends:     a2jmidid
Recommends:     gtk2-engine-clearlooks
Recommends:     libfftw3_threads3
Conflicts:      ardour-vst
Conflicts:      ardour2
Conflicts:      ardour2-vst
Conflicts:      ardour3
Conflicts:      ardour3vst
Conflicts:      ardour4
Conflicts:      ardour4vst
Conflicts:      ardour5
Conflicts:      ardour5vst

%description
Ardour is a multichannel hard disk recorder (HDR) and digital audio
workstation (DAW). It is capable of simultaneous recording 24 or more
channels of 32 bit audio at 48kHz. Ardour is intended to function as a
"professional" HDR system, replacing dedicated hardware solutions such
as the Mackie HDR, the Tascam 2424 and more traditional tape systems
like the Alesis ADAT series. It is also intended to provide the same
or better functionality as software systems such as ProTools,
Samplitude, Logic Audio, Nuendo and Cubase VST (we acknowledge these
and all other names as trademarks of their respective owners). It
supports MIDI Machine Control, and so can be controlled from any MMC
controller, such as the Mackie Digital 8 Bus mixer and many other
modern digital mixers.

%lang_package

%prep
%autosetup -p1 -n Ardour-%{version}

chmod -x doc/canvas.svg
chmod -x doc/mainpage.md

# don't use python2
find . -name wscript -o -name waf -o -name '*.py' \
  | xargs sed -i -e '1{s|^#!.*python$|#!/usr/bin/python3|}'

# Also search vst3 plugins from /usr/lib64 on relevant archs
%ifnarch %{ix86} %{arm}
sed -i 's#/usr/local/lib/vst3:/usr/lib/vst3#/usr/local/lib64/vst3:/usr/local/lib/vst3:/usr/lib64/vst3:/usr/lib/vst3#' libs/ardour/plugin_manager.cc
sed -i 's#/usr/local/lib/vst:/usr/lib/vst#/usr/local/lib64/vst:/usr/local/lib/vst:/usr/lib64/vst:/usr/lib/vst#' libs/ardour/search_paths.cc
%endif

# --no-ytk allows using the system gtk2
%build
./waf configure \
   --prefix=%{_prefix} \
   --libdir=%{_libdir} \
   --includedir=%{_includedir} \
   --configdir=%{_sysconfdir} \
   --docdir=%{_docdir} \
   --docs \
   --internal-shared-libs \
   --with-backends=jack,alsa,pulseaudio \
   --lv2dir=%{_libdir}/%{dirbase}/LV2 \
   --freedesktop \
   --noconfirm \
   --no-phone-home \
   --optimize \
   --no-ytk

./waf i18n
./waf %{?_smp_mflags}

%install
./waf --destdir=%{buildroot} install -v

# upstream installs in wrong places
install -D -m 644 -t %{buildroot}%{_datadir}/metainfo %{buildroot}%{_datadir}/appdata/ardour8.appdata.xml
rm -r %{buildroot}%{_datadir}/appdata

%suse_update_desktop_file -i ardour8 AudioVideo Recorder
%find_lang ardour8
%find_lang gtk2_ardour8
%find_lang gtkmm2ext3

# remove dupes
%fdupes -s %{buildroot}%{_datadir}

%files -f ardour8.lang -f gtk2_ardour8.lang -f gtkmm2ext3.lang
%license COPYING
%doc doc README
%dir %{_sysconfdir}/%{dirbase}
%config(noreplace) %{_sysconfdir}/%{dirbase}/*
%{_bindir}/%{dirbase}
%{_bindir}/%{dirbase}-copy-mixer
%{_bindir}/%{dirbase}-export
%{_bindir}/%{dirbase}-lua
%{_bindir}/%{dirbase}-new_empty_session
%{_bindir}/%{dirbase}-new_session
%{_datadir}/%{dirbase}/
%{_datadir}/applications/%{dirbase}.desktop
%{_datadir}/icons/hicolor/*/apps/%{dirbase}.png
%{_datadir}/metainfo/ardour8.appdata.xml
%{_datadir}/mime/packages/ardour.xml
%{_libdir}/%{dirbase}/
%exclude %{_datadir}/%{dirbase}/templates/.stub
%exclude %{_libdir}/%{dirbase}/libhidapi.a

%changelog
* Mon Feb  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 8.11.0. Check https://ardour.org/whatsnew.html for the
  full list of changes
  * Fix for a critical workflow-blocking bug.
* Fri Oct 25 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.10. Check https://ardour.org/whatsnew.html for the
  full list of changes
  * Fix performance issues caused by scheduling of disk I/O
    threads
  * Importing SMF (MIDI) via drag-n-drop now uses the file name
    once again
  * Small updates to the non-default color themes
  * New MIDI binding map for the M-Audio Axiom 49 MkII
  * New Lua script to duplicate regions on the grid
* Sat Oct 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.9.0. Hotfix release. Check
  https://ardour.org/whatsnew.html for the full list of changes
  * Fix crash caused by a change in how waveforms were drawn
  * Fix bug that caused MIDI notes immediately after the start
    of playback to be ignored.
* Fri Oct  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.8.0. Check https://ardour.org/whatsnew.html for the
  full list of changes
  * Add option to name new MIDI tracks from SMF with just the
    SMF track name.
  * Fix for LV2 plugins whose GUI depend on a "changed" signal
    (e.g. ZynSubAddFX).
  * Fix MIDI Clock output times by using the correct call to get
    tempo at a position.
  * Overdubbing in non-layered mode no longer assignes regions to
    the wrong groups.
  * Add build support for latest versions of macOS.
  * Generic MIDI: do not send touch events for all mapped
    controllers when one is touched.
  * Fix fan-out of instruments with illegal path-chars in their
    name.
  * Require user's own color theme files to be versioned.
  * Fix underruns when looping/locating and changing region
    content.
  * Do not allow changing the loop range while recording.
  * Avoid pixel-level shifts in waveform when splitting or
    trimming regions.
  * Fix playhead moving beyond loop range.
  * Fix count-in/preroll recording offsets.
  * Use dedicated thread to start export timespans.
  * Fix and simplify Playlist::fade_range for multiple ranges.
  * Fix interaction with snapshot list.
  * Fix sample-rate display rounding for 22.05kHz.
  * Fix playback of sessions with low sample-rate.
  * VST3: Fix possible deadlock when using PSL extension for
    sends.
  * VST3: work around plugins that do not heed
    ContextInfo::kSendCount.
  * Fix XML syntax for AKAI MPK mini mk3 MIDI binding map.
- Drop patch, merged upstream:
  * ardour-boost-1.85.patch
* Sat Sep 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.7.0. Check https://ardour.org/whatsnew.html for the
  full list of changes
  New features:
  * Track dragging
  * Ruler changes
  * Midi scene markers
  * Parallel disk I/O
- Add patch:
  * ardour-boost-1.85.patch
* Mon Apr 15 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.6.0.
  * Fix crash when using jack2
  * Fix a drawing bug
* Thu Apr 11 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.5.0. Check https://ardour.org/whatsnew.html for the
  full list of changes
  Improvements:
  * Improvements to AAF import support.
  * Make it easier to use Ardour --gdb on linux by handling SIG32
    automatically.
  * Do not include hidden plugin in plugin-list.
  * Use session-file version as part of backup file names in
    backup/ folder.
  * General MIDI MIDNAM file now includes drum names.
  * Display grid lines for triplets/quintuplets/septuplets.
  * When nudging a single control point, locate to the new
    position to make the time/position clear.
  * Add support for pitch bend to Reasonable Synth.
  Bug Fixes:
  * Fix Snapping quintuplets and septuplets 2x factor grid: fix
    quintuplets 2x factor (septuplets still don't draw properly).
  * Add missing horizontal separator after last track header.
  * Work around itstools bug #9648.
  * Fix undefined symbol when built with VST3 disabled.
  * Disable broken septuplet option.
  * Adding new route in front now works as intended (#9651).
  * Fix jump to next/prev bar.
  * Discard untitled sessions even when not quitting Ardour.
  * Refilling buffers after edits now avoids gaps in audio data.
  * Set correct Timecode widget name.
  * Half-baked automation-point nudge.
  * Fix loading session by relative path.
  * Accumulate IO port-change signals return values.
  * Prevent crashes when trying to add/remove IOPlug ports.
  * Fix a -Wincompatible-pointer-types.
  * Ellipsize inactive track-header name-label (#9674).
  * Prevent double-click on the pianoroll to toggle track height.
  * Clarify that there are no archive file format options.
  * Fix crashing file dialogs - fdopen(3) requires
    _POSIX_C_SOURCE.
  * Set default time domain to Audiotime to sidestep various
    MusicTime issues.
  * Fix solo controller for Monitor bus.
  * Fix potential memory corruption in AVX512f DSP.
* Wed Feb 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 8.4.0. Check https://ardour.org/whatsnew.html for the
  full list of changes
  Improvements and Bug Fixes:
  * Mixer interaction fixes (interaction consistent use of
    button press and release).
  * Lots of miscellaneous color and drawing tweaks.
  * AAF import now (mostly) functional. This is still somewhat
    experimental, but we would welcome feedback..
  * Add metadata to session property editor so that search
    "works" there.
  * Dummy Backend: allow testing with some prime buffersizes.
  * Region groups: do not group multiple takes on a single track.
  * Add a tooltip to describe ops on the pianoroll header,
    incl note select.
  * Don't show plugin preset UI for plugins without controls.
  * New "adwaita" color theme (based on the GNOME Adwaita
    desktop theme).
  * Don't show automation of hidden plugins.
  * Set default MIDI CC values to be more in line with MIDI specs.
  * MIDI notes that were already on/down when recording starts
    are now captured.
  Control Surfaces and Devices:
  * Allow control surfaces to keep editing plugin parameters
    when an unrelated plugin is removed.
  * Adjusted Akai MIDIMix mapping to make solo function as
    described in original user manual provided by manufacturer.
  * Add Lexicon MPX100 midnam file.
  * Add Yamaha SY85 midnam file.
  * Add Donner DMK25 spacline MIDI interface map file.
  * Add a minimalistic Arturia MiniLab 3 map.
  * FaderPort 8: only use visible channelstrip plugins.
  Bug Fixes:
  * Fix sensitivity of macOS global menu at application start.
  * Fix snap to triplet (still no builtin triplet drawing, sadly).
  * MIDI Legatize operation should now function correctly..
  * Escape cue cd-text like toc.
  * Fix crash when using Ripple with a RegionMoveDrag.
  * Allow to use ardour --gdb on newer Linux distros (fixes an
    issue with the way these systems build gdb).
  * Update bundled gdb for windows debug builds.
  * Fix gtk-critical message when monitor section is not present.
  * Fix gdk livelock on Windows when compiled with recent mingw/gcc.
  * Explicitly catch some errors when handling illegal file name
    characters.
  * Do not attempt to save automation data for non-automatable
    parameters.
  * Fix "Ignored automation data for non-automatable parameter".
  * Fix crash (or stuck solo) when removing tracks.
  * Fix crash when session-load fails while creating Routes.
  * Fix erasing events in MIDIBuffer (removing the last event
    marked the whole buffer empty).
  * Fix crash when replicating an LV2 plugin with a different I/O
    configuration.
  * Fix ffmpeg-5+ encoding drop-frame framerates.
  * Fix ACE Compressor inplace processing (when using stereo
    compressor on mono track)
* Fri Dec 22 2023 Christophe Marin <christophe@krop.fr>
- Update to 8.2.0. See https://ardour.org/whatsnew.html for the
  full list of changes
  New features:
  * Change default sample rate to 48kHz.
  * Keep track of the visibility of GUIs for LV2 plugins using the
    externalUI extension.
  * When importing tempo maps from Standard MIDI Files, insert the
    tempo map at the correct position (not always at zero).
  * When editing MIDI notes, show note length with verbose cursor.
  * Add Mute button to recorder view.
  * Allow clearing LV2 plugin scan info.
  * Always allow playback even if there is no session start/end
    defined yet.
  * Improve straight line drawing for note velocity.
  * Handle situations where user's value for XDG_CONFIG_HOME is
    not an absolute path.
  * Optimize tempo map operations for trivial (and overwhelmingly
    common) case of 1 tempo and 1 meter.
* Sun Oct 22 2023 Christophe Marin <christophe@krop.fr>
- Update to 8.1.0. Hotfix release
  * MIDI port names for the Novation Launchpad Pro fixed
  * Varispeed dialog now allows control in percentage units in
    addition to semitones & cents
  * Fix an issue where multichannel tracks would play in mono
  * Prevent time domain (music/audio) confusion when trimming
    audio & MIDI regions
  * When drawing freehand velocity curves, if any MIDI notes are
    selected, only those notes will be modified
  * Fix selection logic when middle-clicking on notes in a MIDI
    track header keyboard
  * Fix a missing label in the insert time dialog.
  * Fix a deadlock ("program freeze") when adjusting a region fade.
  * Allow for bounces with specific source (file) and region names.
  * Include track name when consolidating ranges.
  * Fix potential for duplicated MIDI events with certain signal
    routing.
  * Prevent crash with certain oddly-behaved VST3 plugins'
    response to being asked "do you have an editor?"
  * Add MIDNAM file for Moog Subsequent 37.
  * Remove some cruft from build system scripts.
  * Build system tweak to accomodate newer versions of kissfft
* Thu Oct 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 8.0.0. See https://ardour.org/whatsnew.html
  QoL changes:
  * "Quick groups" - most mix-related controls now operate on
    all the selected tracks & busses
  * Manage sections of a song with arrangement markers. Define
    your verses, chorus, and bridge. Then rearrange or copy
    them as you wish.
  * Create persistent region groups in the editor window, to
    make multi-region editing easier.
  * Edit velocity easily on a dedicated automation lane whether
    it's a single note or a chord.
  * Draw automation freely for any controller or press Control
    (Command) key to enable line-drawing mode. You can also
    combine free and line segments as you draw just by pressing
    and releasing the Ctrl/Cmd key.
  * Fit the tempo map to a human performance, with a new dedicated
    tool.
  * If (e.g. drum) note names are available for a plugin instrument
    or external device (via a MIDNAM file), see those names in the
    all-new MIDI track header.
  * Use Novation Launchpad Pro in DAW/Session mode (along with
    the standalone Sequencer, Note and Chord modes).
  * Create new interesting progressions with arpeggiator plugins.
  New features:
  * Lollipops for MIDI Velocity
  * Improvements to arrangement sections
  * New MIDI Track Piano Roll Header
  * Launchpad Pro support
  * More flexibility to track and bus groups
  * Region Grouping
  * Freehand automation drawing
  * MIDI Arpeggiator Plugins
* Wed Jul 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 7.5.0. See https://ardour.org/whatsnew.html
  New features:
  * Tempo Map Editing
  * Saving I/O Connections Per Device
  * Sections Elements
  * Loaded plugins can now be renamed in the processor box
  * Some of the supported control surfaces now get activated
    automatically upon connection to USB MIDI ports
* Sat Apr 29 2023 Christophe Marin <christophe@krop.fr>
- Update to 7.4.0. See https://ardour.org/whatsnew.html
  New features:
  * Add a volume control to the clip picker.
  * Add a preference item for the PPQN value in exported MIDI files
  * Add an option to use a neutral color for new tracks & busses.
  * Add support for MIDI subgroup busses.
  * Add Lua DSP processor to downmix 5.1 to stereo.
* Thu Feb 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 7.3.0. https://ardour.org/whatsnew.html
  New features:
  * VST3 multi-bus support
  * Searchable Preferences
  * Sample-rate Independence
  * AVX512 support
* Tue Dec 20 2022 Christophe Marin <christophe@krop.fr>
- Update to 7.2.0.
  * New MIDI input port dedicated to controlling trigger slots
  * TouchOSC support improvements
  * MIDI Lyrics Importing
  * Fixes for the tempo maps
  * Fall back to libsndfile if ffmpeg is not available
  * Consistent Audio/MIDI monitor modes
  * UX/UI Improvements
  * Check https://ardour.org/whatsnew.html for the full list of
    changes
* Fri Nov  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.1.0. Bugfix release
  * Ardour now has a Quick Audio Export feature
  * Fixed a few more bugs that could be reproduced when creating
    new MIDI regions or trimming existing one in the part of the
    timeline where a tempo ramp is happening
  * The Cue Markers ruler now has Clear All Cues command in the
    context menu
  * The folder where files from FreeSound are downloaded to is
    now also listed in the clips list.
  * Mixer Scenes Update
  * Revamped the UI for external sends and returns (port inserts)
  * Improved the readability of the X-axis units in the export
    spectogram
  * I/O Plugins ports are now listed separately in the connection
    matrix, with dedicated I/O Pre and I/O Post tabs created
    automatically when you add plugins
  * Better Usability for Automation Editing
  * Improvements in Tempo Map Editing
  * Overall Usability Improvements
  * Check https://ardour.org/whatsnew.html for the full list of
    changes
* Sun Oct 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.0.0
  * arrival of "clip launching" similar to the workflow present
    in all major DAWs
  * New download system to access additional audio / MIDI loops
  * New cue markers rule
  * New and different representation of time than previous versions
  * 3 "ripple editing" modes
  * Ardour can now be used to search and use samples from the
    Freesound project
  * Check https://ardour.org/whatsnew.html for the full list of
    changes
- Add a _constraints files
* Sat Oct 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Remove the source URL. There's no direct download address anymore
* Wed Oct 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tag to GPL-3.0-only. That's the only blocker
  for the factory submission.
* Sat Nov 20 2021 Ben Greiner <code@bnavigator.de>
- Don't use python2 for building
* Fri Aug 13 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to version 6.9.0
  - Plugin Manager
  - Find it under the Window top-level menu
  - The Plugin Manager provides a complete list of plugins that
    were found on your system, and data about each plugin's scan
    results.
  - New standalone scanner applications for VST and AU plugins
    will scan your whole plugin collection without danger of
    crashing Ardour.
  - The new scanner dialog allows you to skip individual plugins
    without canceling the whole scan process. Or set the scanner
    to auto-timeout while you take a break, and come back later
    to re-scan those individual plugins that wanted some user
    input.
  - Sort and filter your plugins by name, brand, tags, or format.
  - Tell Ardour to Ignore troublesome plugins so we won't try to
    load them at all.
  - Ardour loads AU, VST2, VST3, and LV2 format plugins. Choose
    the format that works best for each plugin, and hide the ones
    you don't use (but might be used in some existing sessions).
  - Improvements
  - Playlist Management Substantial changes to playlist
    management include:
  - Global playlist actions like "New Playlist for rec-armed
    tracks" allow you to record a new take on all tracks that
    are record-armed, whether they are in a Group or not.
    You'll find these actions in the Track menu.
  - "Copy Playlist for All Tracks" will store the timeline
    state of your arrangement, edits and automation. You can
    later switch between them while leaving your static mixer
    and plugin settings intact.
  - Select a track and click "?" keyboard shortcut to open the
    Playlist Selector dialog. Click any playlist to listen to
    the alternative takes of that track, OR...
  - ...change the scope to "ALL Tracks" and you can switch all
    tracks that have a matching playlist to your selection: if
    you recorded a take of the drums and bass together, you can
    switch the drum and bass playlists together even if they
    aren't in a Group.
  - Create the perfect vocal or guitar comp: Create a new empty
    playlist and call it 'comp'. Then use the selector to
    switch between different takes and move the best take to
    your comp playlist. You can even have more than one comp
    playlist to compare with each other. And like the other
    playlist functions, you can edit multitracks with ease: by
    group, rec-armed, or ALL tracks.
  - Varispeed Changes
  - The GUI for the "shuttle control" has been modified to
    present a simpler, easier to understand interface.
  - Click on the "VS" button to enable/disable varispeed as
    well adjusting the varispeed settings. .
  - The VS button will blink when varispeed is enabled.
  - Varispeed settings are persistent, so you can revert to
    regular playback, then later re-enable varispeed to get
    back.
  - New GUI control allows blocking MIDI patch changes during
    session loading.
  - Preference items to enable/disable VST2 and/or VST3 support.
  - Add explicit actions for changing between stacked and
    overlaid region views, making this bindable (to a computer
    keyboard or MIDI).
  - LV2 plugins: add support for plugins with multiple Atom ports
    (e.g. Sfizz, the SFZ player)
  - Slip-contents editing now more easily accessible using
    Ctrl-Shift-drag (Cmd-Shift-drag on macOS) anywhere in a
    region. It is no longer necessary to place the mouse cursor
    near the edges of the region.
  - Fix drawing the red recording rectangle to honor latency
    compensation (region no longer visibly jump at rec-stop).
  - Bug Fixes
  - Splash screen management has been changed. On Linux, this may
    conflict with your window manager's behavior - if so, go to
    Edit > Preferences > Appearance > Quirks and try the
    "Show/Hide" setting.
  - Support for a Wine/windows build to run Windows VST plugins
    "natively" on Linux has been removed. ardour.org has never
    distributed these builds. There are plugin wrappers/bridges
    such as Yabridge that do a better job of making this
    possible.
  - Muted MIDI regions are now actually muted.
  - MIDI capture duration is correctly computed when loop
    recording.
  - MIDI capture alignment is now correctly implemented.
  - Loop recording working again after an unnoticed breakage.
  - Various fixes for recently added region markers during
    editing.
  - The "Escape" key now behaves identically while in internal
    editing modes as when in other mouse modes.
  - Prevent accidental addition of multiple markers at the same
    position.
  - In the Recorder tab, do not show input meters for
    control-only ports Faderport, Mackie, etc.
  - During a slip-contents drag, regions are now transparent so
    that you can align transients.
  - Fix Apple Coreaudio Source (used for MP3 import on macOS) --
    was broken since 6.0
  - Control Surfaces
  - US2400: Fix direction of pan knob LEDs.
  - Mackie Control
  - Change combined meter to use a peak meter with falloff.
  - Reset surfaces once connected.
  - Correctly handle the Monitor section being removed.
  - Update the meters even when the transport is stopped.
  - Move meter deflection calc to a function.
  - Improved support for iCON QCon Pro X.
  - When reconnecting ports, don't give up on first failure.
  - Don't call port write directly since it bypasses active
    chk.
  - Improve debug trace output by skipping meter write output.
  - Hold the surfaces lock while resetting the master_surface.
  - Don't crash when the master is on the right.
  - Use selected device's info when building the Keys dialog.
  - Fix one off error in timecode display that broke spaces.
  - Use space as replacement for invalid characters on timecode
    display.
  - Fix logic in timecode display update.
* Tue Jul  6 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to version 6.8.0.
  - New Features
  - Playlist Operations (sponsored by Harrison Consoles) A new
    menu Track > Playlist, provides actions to create new
    playlists (or a copied playlist) for (all | rec-armed |
    selected) tracks.
    Playlist naming and grouping behavior has changed:
  - When creating a new playlist, the user is always prompted
    for a playlist name (default value is Take.N where N
    auto-increments). In the past, some playlist actions didn't
    prompt for a name while others did, resulting in
    inconsistent naming.
  - When a playlist is created, ardour assigns it a group-id
    (timestamp) which can later be used to recognize playlists
    that were created as part of the same action. In the past,
    ardour tried to match grouped playlists via name but this
    relationship was unclear to the user.
  - A playlist group-id is also implicitly created when you
    first record to an empty playlist. This solves the problem
    in the past where user-created playlists would select
    together as a group, but the initial track playlist had no
    group relationship and therefore could not follow the group
    selection.
  - The dialog accessed via the "P" button in the track header
    (editor view) has been adjusted: some esoteric playlist
    functions (copy from other track, share from other track,
    and steal from other track) are now hidden under an
    "Advanced" submenu. You can now also show more than one
    track's "Select Playlist" dialog simultaneously, the dialog
    is persistent rather than closing when you make a
    selection: this makes it easier to audition playlists
    ("takes") and copy from one to another
  - Performance Meters: Window > Performance Meters now provides
    low level metering of the "DSP" taking place inside Ardour.
    Notice that the numbers display in the window are worst case
    which may not match the behavior of some other measurement
    tools (e.g. the main "DSP meter" in the upper right of the
    main window) or other DAWs. Average values (along with std.
    deviation values) can be seen by mousing-over any given
    meter. Thanks to Robbert van der Helm for his participation
    in the development process for these meters.
  - Add support for requesting specific CPU DMA latency values
    (can improve DSP performance on some systems, and degrade it
    or have no impact on other systems). If you don't understand
    what this does, then it's probably best to leave it alone.
  - Add extend-selection (to end of region) and invert-selection
    operations for MIDI editing
  - New track edit operation "remove gaps", with adjustable
    threshold and "leave" parameters
  - Add M4A import support
  - MIDI Tracer windows now come with their own port for
    arbitrary tracing of MIDI data
  - Improvements
  - Add bypass control to ACE-Fluidsynth
  - Add a MIDNAM file for Yamaha P-121/125 keyboards
  - Do not trigger ruler display when changing between BBT
    subdivisions for the grid
  - Crash fixes and speed improvements to ProTools session import
  - Allow renaming of region/source cue markers
  - Allow drag of region/source cue markers
  - Alternative region/source cue marker promotion to CD markers
  - Stop using named semaphores on system wide to avoid
    collisions with other software
  - Ignore xruns when when switching to/from non-realtime export
  - Remove duplicates in CoreAudio device list
  - Refactoring of input port monitoring (significantly reduces
    DSP load caused by new recorder tab)
  - Improvements to setting real-time priority for critical
    threads
  - Better event loop integration for websocket support
  - Automation control points no longer obey "lock edit" mode,
    which should only lock regions and notes
  - Slip-contents drag made more accessible
  - Some improvements to behavior of brush dragging
  - Override global Ubuntu menu behavior
  - Improvements to splash window visibility management during
    startup
  - Bug Fixes
  - Fix memory leak in clock displays (up to 50MB/hour when
    rolling)
  - Fix undo/redo of ripple edits
  - Fix disappearance of regions and sources from lists in the
    Editor
  - Fix behavior of "transport-play" operation from control
    surfaces
  - Fix crash during MIDI bounce with processing
  - Fixes for hangups during multiple timespan export
  - Fix crash when removing a plugin with a control mapped using
    MIDI learn or a binding map
  - Fix crash when using external position sync (MTC, LTC etc)
    and switching backends
  - Fix deadlock in long running sessions (2-5 days)
* Mon May 31 2021 munix9@googlemail.com
- Update to version 6.7.0.
  * New Features
  * Dedicated “Recorder” tab/window
  - Provides a compact view of your track’s record & monitor status plus a simplified timeline that keeps everything in view at once.
  - Allows you to rename your device’s hardware inputs to match your studio connections: “Vocal Mic”, “Guitar Mic”, “Bass DI” (these names will be retained across sessions).
  - Every hardware input has a high-precision meter with peak-hold, a scrolling waveform history so you can recognize your source signals, and a PFL solo button to listen to that signal (requires the Monitor section to be engaged).
  - Vision and support for this work came from Harrison Consoles.
  * New "Streaming" preset option for export (defines correct defaults for YouTube, Apple Music, SoundCloud and Amazon Music streaming services, particularly loudness levels).
  * Allow import of SMF (MIDI) cue markers as global markers.
  * Improvements
  * Improvement in GUI drawing speed on macOS (snappier, more responsive feel, less CPU load).
  * Preferences window/tab significantly re-organized.
  * Overhaul LAN dialog: add loudness graph, allow for custom presets, update layout to always show conformity analysis.
  * Warn if the audio interface to be used differs from the one last used with the session.
  * After drawing automation, automatically switch that parameter to "Play" mode.
  * Allow "all-in" and "all-disk" monitoring options to be selected at the same time (just as we do for individual tracks).
  * The tab/window select buttons at the upper right now use verbs to describe what you're doing
  * Fix pasting processors in pre-fader position (they would end up in an unpredictable position).
  * Keep mixer input/output buttons updated if available ports and groupings of ports change.
  * Big clock window now correctly shows recording state.
  * Audition tool correctly controls transport speed.
  * Catch up with latest version of liblo (used for OSC support).
  * Add preference to keep auto-spilled automation-lanes visible.
  * Rename "Plugin Manager" to "Plugin Selector".
  * MonitorSection: fade input in/out for AFL/PFL.
  * Allow re-try when session-parameters mismatch.
  * Allow auto-spill-on-touch for Fader,Trim,Panner and Mute controls.
  * Allow removal of all xrun markers.
  * Return/Enter does not have special behavior in the processor box.
  * Make cursor visible on mixer strip gain entry.
  * Increase visual contrast of insensitive faders.
  * Change Solo button tooltip when using A/PFL.
  * Foldback: spill follows selection.
  * Foldback: improve GUI consistency.
  * Add A/PFL button to foldback strip
  * Spill only direct feeds - if track A sends to bus 1 which sends to bus 2 and you spill bus 2, only show bus 1, not track A
  * Consistent "add track/bus" widget in recorder, editor and mixer tab
  * Make group tabs insensitive when spilling sends
  * Open add-route dialog on double-click or context-click in "empty space"
  * Implement zero-latency convolver (available to Lua scripts).
  * Indicate ambiguous latency, which can lead to capture alignment issues.
  * Recover waveform-gradient-depth slider for ardour, and timeline-item-gradient-depth for mixbus.
  * Include a loudness plot on export-report.
  * Tweak export-report to fit on smaller screens (#8698).
  * Set default master-bus meter-point to output.
  * Overhaul export loudness normalization (include limiter).
  * Disambiguate export formats with same loudness but different true-peak.
  * Improve GUI behavior of the tempo dialog by preselecting the start BPM text field.
  * Use -90dB as default threshold for silence trim during export, rather than -inf dB.
  * Primary-w now closes Preferences window (like any other dialog/window).
  * Inform user if there have been dropouts during realtime export.
  * macOS: improve realtime thread scheduling.
  * Rewind/ffwd controls can now optionally act more like a shuttle (incremental) speed control (see Edit > Preferences > Transport).
  * Reduce default maximum transport speed to 2.0 to avoid DSP overload.
  * Add new config parameter for auto-return after rewind/ffwd (set to false by default).
  * Significant optimizations to speed of many operations affecting multiple regions.
  * Use sub-menus for automation parameter selection if a processor (e.g. plugin) has more than 32 automatable parameters.
  * Ignore JACK2 xruns during freewheel export for now.
  * Redesign color mgmt when entering/leaving markers of various kinds.
  * Change chat URL used via About > Chat to one that redirects via ardour.org, reflecting turmoil on the Freenode IRC network.
  * Bug Fixes
  * Fix Windows process thread priorities.
  * Fix double region freeze, stuck changes (#8701).
  * Fix session loading when aborting latency measurement (#8691).
  * Fix export race condition (and crash).
  * Update drag-n-drop mininum movement threshold (#8686).
  * Fix several incorrect transport behaviors.
  * Fix crashes when rippling many regions.
  * Fix incorrect port lists due to using a custom sorting method.
  * Use correct harvid bind address on BigSur.
  * Loading old route-templates now working.
  * Use correct insert-position when adding route from template.
  * Correct behavior when dragging a region to the dropzone (#8672).
  * Video-monitor display fixed when locating.
  * Fix deadlock when duplicating regions w/ripple.
  * Fix insert + ripple undo/redo.
  * Fix crash when consolidating range with automation.
  * fix "trim to loop" region edit operation so that it applies to any region that intersects the loop, not just those spanning it.
  * Fix shuttle wheel semi-tone mode.
  * Ctrl-surface: do not name single-channel bundle ports.
  * Consistent port-matrix channel name display.
  * Fix crash if no audition synth is unset.
  * Fix blurry text in connection manager.
  * Remove redundancy between CD and DVD-A export formats, which are identical.
  * Fix formatting of `-inf' on some Windows systems.
  * Fix BPM button text display on Windows.
  * Fix possible BPM button text overflow.
  * UTF8 compatibility with default windows font.
  * Fix undo after non-layered record pass.
  * Fix crash at exit with classic Faderport.
  * Include Tracks and Busses in connection dropdown (#8636).
  * Avoid a crash when reopening a session saved with selected MIDI notes.
  * macOS: Fix crash when timing issues alter startup process.
  * Correctly show splash screen content.
  * Fix a crash when separating ranges that include automation.
  * Don't put empty "split" commands on the undo/redo list.
  * Fix session-archive extraction on Windows.
  * Prevent use of "recorder:" in audio/MIDI file names (causes strange issues on Windows).
  * Fix potential issue during creation of session archives on macOS.
  * Fix for lost/empty MIDI files when using snapshots (#8552).
  * Fix analysis chunksize to be multiple of channel-count (#8631).
  * Fix crash when removing custom transients.
  * Fix export-analysis true-peak display offset when stripping silence (#8578).
  * Collect Playlist::ContentsChanged() signals (#8626).
  * Ignore pinout when copy/pasting plugins using Ctrl+c/v.
  * Code changes to support newer glib definitions for atomic variables (no volatile specifier).
  * Fix display of region peak information for trimmed audio regions.
  * Foldback: fix removing last fb bus.
  * Fix A/B plugins, skip internal but visible plugins (e.g. LAN).
  * Improvements in audio/MIDI Backends
  * ALSA (Linux): add option to prefer interleaved access.
  * ALSA (Linux): Fix swapped systemic latencies.
  * ALSA (Linux): handle asymmetric systemic latencies correctly.
  * PortAudio (Windows): Fix a problem with ASIO buffer sizes.
  * Plugin-related Changes & Improvements
  * VST3
  - Linux: prevent registering multiple identical file descriptors.
  - work around plugins with missing controller state.
  - Fix MSVC related crashes.
  - Add option to not show Micro Edit ctrls by default.
  - Prevent recursive endless resizing.
  - on macOS, add entitlements to get plugins working.
  - pass a read-only state stream to the plugin (#8642).
  * VST2
  - Support MacVST2 plugins with multiple child views (e.g. UAD).
  - Fix enter/return ambiguity -- thanks to falktx.
  * macOS (VST and AU)
  * Fix Mac Plugin re/sizing.
  * Included Plugins
  - a-delay: BPM is independent of the meter (quarter notes / min).
  - a-fluidsynth updated to use Fluidsynth 2.2.
  * Control Surfaces
  * Various: Fix one off in calculation of fader position.
  * Binding map for Maschine Mikro MK2.
  * Binding map for Alesis_VI25.map.
  * Mackie Control: device description and profile for Arturia MkII keyboard/control surface.
  * Mackie Control: if master surface has a jog wheel *and* a scrub button, button toggles between scroll and shuttle behavior.
  * Mackie Control: set select state correctly during initial setup.
  * Mackie Control: Don't crash if master fader is not avaliable.
  * Fix OSC "/marker" feedback.
  * Lua Scripting Changes & Improvements
  * Add Lua Bindings to access Bundles.
  * Add lua methods to control range locations.
  * Prevent denormals in Lua DSP state (LPF, Biquad).
  * Add Lua binding to rename session.
  * Fix Lua `get_processor_param` API.
  * Fix Lua bindings for C++17/C++20 (#8683).
  * Add Lua bindings to modify region gain curve.
  * Lua API for sends, sidechains and monitoring.
  * Add a Lua binding to determine Ardour version.
  * Theme Updates
  * Update Clear Gray RecBox, and Cubasish theme colors.
  * Translation Updates
  * French.
  * German.
  * Russian.
  * Enable libpulse, libwebsockets, soundtouch
  * Clean up spec file
* Wed Feb 24 2021 andy great <andythe_great@pm.me>
- Update to version 6.6.0.
  * New Features
  * Option to automatically show automation-lane when touching a control. (Edit > Show Automation Lane on Touch)
  * Auto-shown automation parameters automatically put into touch mode upon graphically adding a new control point (this and the previous change makes editing automation much simpler/faster than it has been).
  * Verbose cursor audio region peak display - press Alt or use internal edit mode ('e' shortcut) to see audio peak levels in an audio region.
  * Keep track of xruns (overruns/underruns) per file when recording
  * Option to how x-run markers in regions.
  * Show x-run count in source-list by default.
  * By default, don't create timeline x-run markers.
  * Show per-region x-run markers by default.
  * ACE Fluidsynth plugin can now process MIDI sysex messages, in particular MIDI Tuning Standard (MTS) messages.
  * New Lua script to send tuning defined in a Scala file as MTS messages.
  * New Lua script to send arbitrary 12TET tuning (A = XXX Hz) as MTS messages.
  * The density (pixels-between-lines) for the editor grid is now user-configurable.
  * Ruler can now show 1/64th and 1/128th note positions when appropriate.
  * MIDNAM file for the Moog Grandmother.
  * Improvements
  * Issues with snapping to grid fixed (or at least, dramatically improved).
  * Improve MIDI note selection behavior to be more consistent with selection rules in general.
  * Now possible to close & save even if the audio/MIDI engine is stopped.
  * Eliminate/reduce fuzzy font rendering on many buttons (for HiDPI displays)
  * Improving sizing of certain GUI elements containing variable text.
  * Improved appearance for the BBT ruler.
  * Prevent additional mouse button presses while dragging from interfering with the drag.
  * Add new user option to control whether or not the default transport speed is reset when stopping (true by default).
  * Clicking an automation track when in object/grab mode now adds a new automation point, making line drawing easier.
  * OSC: commands targeting "strip" or "select" now use the same code for better consistency.
  * OSC: Allow to specify marker name
  * Creating monitor-sends from templates now functional.
  * Bail out if export cannot be started.
  * Do not bother to render waveforms in tracks displayed with extremely small heights.
  * video-export dialog: only show abort/progress when exporting.
  * Safely handle removal of sidechain input.
  * Ignore inline-display unless plugin-meta data explicitly mentions it.
  * Do not allow feedback override on foldback sends.
  * Add input port signal meters, scopes and monitors.
  * Add option to skip MIDI track input auto-connect.
  * Indicate that plugin-window MIDI keyboard is not recorded.
  * Sort input port signal meters by port name.
  * More use of port "pretty names" (user-assignable names for all ports)
  * VKeybd: include port-name in dropdown.
  * VKeybd: show pretty-name in port-connector.
  * Implement dynamic input port meters.
  * Micro-optimization: pre-calculate pan-law.
  * Hide "Midi Through" ports on Linux only.
  * Hide hidden ports in port-matrix.
  * Report failed connections when reconnecting ports.
  * Retain "Virtual Keyboard" pretty name across engine restarts.
  * Update Ctrl-surface MIDI port list when ports change.
  * Disable vertical autoscroll for UI (editor) elements where it doesn't make sense.
  * Expose resampler quality (read-only)
  * Consistent naming of mixer strip processors used for disk reading/writing.
  * Updated MIDNAM file for Waldorf Blofeld.
  * Various fixes for the MSVC project files.
  * Bug Fixes
  * Problems with playhead movement while rewinding fixed.
  * Stop after locate-while-rolling now works (again).
  * Prevent silentfile over-read
  * Fix mix-buffers-with-gain FMA (SIMD) implementation to avoid crackling in some situations
  * Fix implicit Vkeybd MIDI meta-data.
  * Fix Faderport1 port-connection.
  * Fix typo in vst3-scanner --help text.
  * Fix Aux-send copy/paste.
  * Fix mp3 and video-export (ffmpeg/ffprobe detection)
  * Fix send panner when copying sends.
  * Fix fader font-size.
  * Fix bugs where multiple threads tried to read from the same AudioSource (file)
  * Fix invisible multicahannel waveform at rec-stop.
  * Fix default track name patterns, remove additional space.
  * Fix crash when requesting disk/in monitoring of busses.
  * Fix tracking-text offset.
  * Fix typo in OSC gain feedback message.
  * Fix deadlock during export.
  * Fix latency compensation for newly created tracks when using the JACK audio/MIDI backend.
  * Fix automation context-menu state when reordering plugins.
  * Fix crash when detaching Editor or Mixer w/o session.
  * Fix mixer initial group-tab display.
  * Fix race condition when deleting tracks.
  * Fix round-corner backround of insensitive ArdourWidgets.
  * Fix renaming export timespans.
  * Improvements in the ALSA audio/MIDI Backend
  * Set pretty port names for audio I/O
  * Fix slave device lookup.
  * Fall back to nearest available buffer-size, rather than report an error
  * Explicitly list millisecond buffer-sizes (helps with some newer laptop builtin audio interface that only support millisecond-sized buffers).
  * Allow selection of clock-source when using multiple devices
  * Retain port-connections of slave devices.
  * Plugin-related Changes & Improvements
  * VST3
  * Improve verbose scanner output.
  * Allow multiple identical timer-handlers
  * Allow multiple file descriptors per plugin UI
  * Announce IPlugFrame interface support.
  * Always pass buffers for all audio busses.
  * Set I/O correctly.
  * Pre-allocate AudioBusBuffers.
  * Fix VST3 path customization.
  * Fix plugin bus configuration.
  * Use a proxy for connecting and passing messages #8481
  * Allow filename mismatch inside the bundle.
  * Backport VST3/musl support
  * LV2
  * LV2 "uri-map" extension no longer supported.
  * Fix LV2 boolean Atom values size #8558
  * Fix ACE.lv2 inline-display meta-data.
  * Tweak fluidsynth performance on ARM CPUs.
  * ACE Fluidsynth: consistent port-names.
  * AudioUnits: Fix variable I/O instruments.
  * VST2: relax MIDI port detection.
  * Lua Scripting Changes & Improvements
  * LuaDSP use vectorized peak-finding.
  * Add Lua bindings to modify plugin pin bypass/thru-map.
  * Add Lua binding to get a file's basename.
  * Luasession: load default session snapshot.
  * Allow cast of ControlList to AL (for undo)
  * Extend plugin parameter Lua bindings.
  * Add Playlist::set_name() Lua binding & unique name check.
  * Allow Lua bindings up to 11 args.
  * ProTools Session Import
  * Race condition (random crashes/issues) fixed while creating audio tracks.
  * Track naming scheme improved.
  * Progress bar now covers entire import process.
  * Import -> Cancel -> Import workflow now possible.
  * Fixed crash while bringing in audio material from PT session.
  * Translation Updates
  * German.
  * Chinese.
  * Russian.
* Wed Nov 25 2020 andy great <andythe_great@pm.me>
- Update to version 6.5.0.
  * New Features
  * Support for plugins in VST3 format
    (for Linux, Windows and macOS)
  * Visit Preferences->Plugins and click "Scan Now" to find
    your installed VST3 plugins.
  * There is no need to set search paths for VST3's though you
    can specify additional folders to search if you do not
    install them in the VST3 standard location).
  * By default, if a plugin is available in both VST3 and VST2
    then only the VST3 will show up in your plugin list.
  * VST3 support includes support for the Presonus VST3
    extensions, as use by (for example) Softube Console1
    plugins and control surfaces.
  * Improvements
  * Prevent Session range markers from being hidden.
  * Reduce the amount of work done when multiple locate
    commands are all issued in a very short time.
  * Significantly speed up displaying of all MIDI automation
    lanes.
  * Ask before showing 2000 automation lanes (can occur with
    certain plugins present on a track).
  * Mark sessions as dirty if a meter type is changed.
  * Improve various details of signal path latency
    computations.
  * Use linear fades when crossfading loop end/start.
  * Slightly speed up stem and direct-out export.
  * WAV and AIFF files may now include session meta data tags
    (using id3v2 tags and WAV Info).
  * Bug Fixes
  * Correctly sort concurrent MIDI events.
  * Check for MIDI buffer overflow when merging into an empty
    buffer.
  * Complain when MidiBuffer::merge_from fails due to buffer
    full.
  * Fix a rare but important race condition bug in the code used
    to manage several critical real-time data structures.
  * Fix handling of musical times between 0 and -1 beats.
  * Fix handling of transport manager ports when switching
    session.
  * Fix external/sidechain send solo propagation.
  * Cursor position and text color when editing clocks fixed.
  * Fix restoring implicit solo on session load.
  * Fix the window a plugin GUI/editor floats over when using a
    detached mixer window.
  * Fix AudioUnit window size for some non-resizable plugins.
  * Fix various issues when using MIDI on ARM (Raspberry Pi).
  * Fix bounce & freeze operations:
  * Include main-out channel-count when bouncing the output
  * Do not de-activate disk-reader and mains-out when freezing
    a track
  * Ignore meter when counting channels
  * Control Surfaces
  * Handling of MIDI encoders in "Generic MIDI" support is fixed.
  * Websocket/JS support now properly supports MIDI strips.
  * Lua Scripts
  * Fix for a bug in the "Tom's Loop" script.
  * MIDI rewriting example script has been made more elaborate.
  * Included Plugins
  * Plugins previously in the "a-*" family are now consistently
    referred to as "ACE" (Ardour Community Effects).
  * Theme Updates
  * A few tweaks in the "dark colors" theme.
  * Translation Updates
  * Basque
  * German
  * French
  * Russian
- Ardour 6.4.0 was released but immediately superceded by 6.5.0.
- Mark locale-dependent files with %%find_lang macros.
- Exclude static library, libhidapi.a.
* Thu Oct 29 2020 andy great <andythe_great@pm.me>
- Update to version 6.3.0.
  * New Features
  * Loudness Analyzer & Normalizer. Calculates the Loudness
    (LUFS) of the session (or a range selection), and add a
    gain-stage to the master-bus to normalize the loudness
    according to various standards. There's also an additional
    "Conformity Check" for many common distribution targets
    (YouTube, SoundCloud etc. etc.). Thanks to Ardour/Mixbus user
    BachStudies for the nerdsniping encouragement and design
    ideas for this feature.
  * AVX-optimized metering code for Linux.
  * Neon-optimized metering code for ARM platforms.
  * Double-click on track header (in Editor view) expands and
    contracts track height.
  * Inactive tracks (in Editor view) now only show the track
    name, to emphasize their inactive state.
  * Compile-time option to use SoundTouch for vocal time
    stretching
    (this is not currently enabled for ardour.org builds).
  * Improvements
  * Foldback busses now default to pre-fader position, as
    intended.
  * Added full GUI for setting foldback bus position to pre/post
    fader.
  * Allow name and path column in editor source list to be
    manually resizable.
  * Nudge forward and backward key bindings now work in the
    editor.
  * Engaging loop play while rolling with no audio tracks now
    works.
  * Dramatically speed up MIDI file loading by removing the
    seconds/time API from libsmf. An example "black MIDI" file
    with 24,134 tempo changes now takes 5 seconds instead of 5
    minutes to load.
  * Slider controller (used in many places in the GUI) now
    accepts dB when it controls gain, rather than a simple
    numerical gain coefficient.
  * Do not auto-save when importing video.
  * Fix audible amplitude modulation in de-click fade.
  * If Ardour is the JACK Transport time master, it now supplies
    the bar start tick data.
  * Ardour's custom knob in the GUI now shows when it is
    insensitive to user-interaction.
  * Do not include VST parameters marked as non-automatable in
    list of automatable parameters.
  * Prompt user for name when doring Range or Region bounces
  * Add capture-for and channel count columns to the editor
    Source list.
  * Allow editing the name field in the editor Source list to be
    edited.
  * When consolidating a range of MIDI data, the new region
    should fill the range, not stop at the end of the existing
    MIDI content.
  * Add a take-ID to bounced regions, so that multitrack bounces
    can be sorted/recognized in a list.
  * Bug Fixes
  * Auto-play when locating to session start is now honored
    (again).
  * No more (small) delay when starting to record while already
    rolling.
  * Various fixes related to auto-connecting track outputs,
    particularly MIDI tracks.
  * AudioUnits: do not call render callback for disconnected
    busses (fixes various 3rd party plugins).
  * Ensure audio engine is active when doing plugin scans, since
    some 3rd party plugins try to access it (indirectly).
  * Windows version now set HiDPI settings (may fix font
    aliasing issues on that platform).
  * Fixed crash when removing master bus output channels.
  * MIDI capture alignment fixed.
  * Fix crashes when editing automation points.
  * Fix occasional deadlock at session close.
  * Fix occasional issues with mute button visibility in Master
    bus mixer strip.
  * Control Surfaces
  * New MIDI binding map for AKAI MPK249.
  * New MIDI binding map for Arturia Minilab Mk II.
  * Browser-based (WebSockets + Javascript):
  * Many improvements in stability, usability and what is
    represented in the browser control surface .
  * OSC:
  * panner type can be set (within the limits derived from I/O
    configuration).
  * panner type feedback added.
  * automation control for pan and trim gain added.
  * toggle-roll can be used to pause or return to start, as
    expected.
  * Lua Scripts
  * Lua bounce script improved.
  * Lua meter point script fixed.
  * Lua access to Transport State machine provided.
  * Improvements to "List Plugins" script, which is now
    automatically loaded at startup.
  * Included Plugins
  * Polyphony count for a-fluid (SF2 player) increased .
  * Add crossfade and A/B plugins.
  * Translation Updates
  * German.
  * Italian.
  * French.
  * Updates for 6.2
  * New Features
  * Plugin list in the mixer view can now toggle between
    "Favorite", "Recent" and "Popular"
    (based on your own usage).
  * "Insert random noise bursts" option in the export dialog
    allows you to deliver non-publishable mixes to clients for
    preview.
  * New option to control placement of ellipses within long
    track names.
  * New script to read Scala files and generate MIDI Tuning
    Standard system exclusive messages.
  * Improvements
  * "goto-mark-x" action now available for binding in the
    mixer.
  * Certain unconventional and sometimes invisible characters
    in session names no longer lead to undefined behavior.
  * "Loop Range" action in marker menu now works as intended.
  * When carrying out various MIDI editing on linked regions,
    be sure to apply them only once to the MIDI data shared by
    all the regions.
  * Control surface/protocol names now shown in alphabetical
    order.
  * Improve situation with deciding on which language to use
    for translation on macOS when user has more than one
    lanugage in use.
  * Improved accuracy for MIDI Clock output.
  * Keep aux send names when duplicating tracks.
  * Retain connections to MIDI ports marked for use as control
    data.
  * Automatically switch to input metering for MIDI tracks when
    they are record-enabled (like audio tracks).
  * Plugin preset is now marked modified when LV2 plugin
    parameters are modified, even if done directly by the
    plugin.
  * man page updated.
  * Updates to the unastudia theme.
  * Emphasize beat lines via modified theme colors.
  * Bug Fixes
  * Reverse MIDI playback now works (again).
  * MIDI Clock transport sync now working (again).
  * Fix display of time in MIDI tracer window for certain kinds
    of MIDI ports.
  * Automation write mode now correctly overwrites existing
    automation (again).
  * Fix deadlock/crash when adding a sidechain port to a
    plugin.
  * Opening sessions from Finder on macOS now works (again).
  * Deeper handling of thread stack size limits on various
    Linux distributions.
  * Fix playback after solo-section has been used.
  * Auto-play now works after dragging the playhead (again).
  * Fix audible blips caused by inconsistent monitoring state.
  * Fix the behavior of automation points when performing a
    ripple edit.
  * Numerous other minor bugs fixed.
  * Control Surfaces
  * Browser-based:
  * More compilation compatibility with different versions
    of libwebsockets.
  * Improvements in client-side code components.
  * OSC:
  * Foldback sends can now be pre- or post-fader.
  * Allow foldback bus duplication.
  * Strip width feedback added.
  * New support for the original Contour ShuttlePRO.
  * Nektar Panorama map should now be visible.
  * Fix panning knob control/directionfor CC121 and US2400.
  * New MIDI binding map for M-Audio Oxygen 25
    (3rd generation).
  * Included Plugins
  * Add Dotted option for a-delay, since dotted intervals
    cannot be expressed with just integer divisors .
  * Translation Updates
  * Japanese
  * French
  * Basque
  * German
  * Italian
* Wed Jul  8 2020 Gustavo Boiko <boiko@suse.com>
- Fix installation path of built-in LV2 plugins
* Thu Jun  4 2020 Eymeric Dechelette <hatchchien@protonmail.com>
- Update ardour from 5.12.0 to ardour 6.0.0 :
    It make better :
    Full latency compensation everywhere
    Global varispeed
    Cue Monitoring
    Wet Recording
    Grid/Snap
    MIDI handling
    Plugin management
    It add :
    new Audio/MIDI Input & Output
    new File Formats, Import, Export Etc.
    new Platform Support like arm binary netbsd freebsd and open Solaris
    some Miscellaneous
    See the full list at : https://ardour.org/whatsnew.html
-  remove patch (ardour-internal-qm-dsp.patch and fix-fluidsynth-2.patch) because they were only needed for ardour 5.12.0
-  enable translation
* Sat Mar 21 2020 Dmitry Roshchin <dmitry_r@opensuse.org>
- Drop Wii Remote support (cwiid was removed from Tumbleweed)
* Tue Mar 13 2018 9+suse@cirno.systems
- Remove dependency on suil-plugins
  Not actually required. Also, this package no longer exists in TW.
* Mon Dec  4 2017 9@cirno.systems
- Update to 5.12.0 -- Many new features and fixes
  See https://community.ardour.org/releases
- Add ardour-internal-qm-dsp.patch
  Ardour needs qm-dsp. This is not yet packaged by openSUSE,
  and it apparently also expects this to be a snapshot rather
  than a release version. Hence this package uses the bundled
  copy.
- Install bundled/generated .desktop/MIME files and icons,
  drop them from the package repo
- Drop cwiid dependency as Ardour expects a snapshot which is not
  (yet) packaged by openSUSE
- Use python3 for build, drop unused module dependencies
- Add MIME/desktop database post/postun macros
- spec-cleaner, use pkg-config
* Tue Aug 23 2016 stephan.barth@suse.com
- added Recommends: libfftw3_threads3. Otherwise there is no dependency on
  it.
* Tue Aug 23 2016 stephan.barth@suse.com
- update to version 5 with a lot of new features and fixes. See the full list
  at https://community.ardour.org/node/13842
- New binary %%{_bindir}/ardour5-copy-mixer
- added BuildRequires fftw3-threads-devel
- adjusted dirbase variable, ardour4.png, ardour4.desktop, ardour4-rpmlintrc,
  %%{_bindir}/ardour4-export and suse_update_desktop_file call to ardour5*
- removed obsolete patches which were actual backports before:
  * ardour_fix_no_return.patch
  * ardour_fix_new_session.patch
- removed %%{_datadir}/%%{dirbase}/pixmaps/*
- marked %%lang files in the %%files section with %%find_lang
* Wed Feb 10 2016 someuniquename@gmail.com
- delete unneeded libgnomecanvas dependency
- delete gtk2-clearlooks theme dependency
- backport https://github.com/Ardour/ardour/commit/05e59a0
  - fix new session creation
- backport https://github.com/Ardour/ardour/commit/d1c3563
  - fix pedantic compiler warnings
- update to version 4.6
    Plugins (Platform-Independent)
    Add a check button in the session loading dialog to disable all plugins.
    Improve layout/appearance/functionality of Plugin Manager dialog.
    Fixes for compatibility with LV2 1.0.0.
    Clicking on a plugin LED holding Ctrl-shift toggles all plugins/processors in this strip (except the fader).
    Fix monitoring of plugin parameter changes with LV2 and AudioUnit plugins, to avoid feedback loops between the plugin and the GUI.
    Fix an issue with loading sessions containing certain LV2 plugins.
    Show VST plugin search paths (read-only) in Preferences dialog.
    Fix LV2 plugin state for copied plugins.
    Properly copy plugin state when duplicating tracks/busses.
    Save/restore plugin states as part of track templates.
    GUI
    Report on progress while stripping silence from tracks.
    Fix fine-adjust modifier overriding snap modifiers.
    Clicking on an already selected note when many are selected makes it the only selected note (same behaviour as regions and control points).
    Allow use of tooltips to be enabled/disabled from Preferences.
    Mixer list pane can now be shrunk to zero width.
    Dialogs and unparented windows now default to the current pointer position.
    Add relative snap when moving markers.
    Increase the minimum size of the recent session scrollview.
    Don't make hidden automation controls visible, ever.
    Allow numerical entry for setting gain values in Preferences dialog.
    Show an informational dialog when opening IRC via Help -> Chat, to try to clarify to new users that they should post a question and then wait, not leave after a few minutes.
    When adding a single plugin, immediately show the plugin GUI (except when using drag-n-drop to add the plugin).
    Improve the layout of various widgets in the Preferences dialog.
    Add "Delete all Unused Playlists" and "Keep All Playlists" options to cleanup dialog.
    Fix "Crop to Range" operation to include all (selected) regions covered by the range, not just those that cover the start.
    Fix "Fill Track" to avoid single-sample regions.
    Keep track of meter visibility.
    Hide region frame outline when region is less than 2 pixels wide.
    Continue normal scrolling if the pointer is over the dropdown menus in the track header of a MIDI track.
    Fix misplacement and improve grouping of various audio and MIDI ports in patchbay(s).
    use the correct environment variable to block loading of GTK+2 resource files (changed back in 2002 but never updated in our source code).
    Makes rows in the theme manager selectable, making it easier to link an object to a color.
    Fix incorrect keyboard focus after deleting a marker.
    Allow hiding and showing the mixer list.
    Disable threaded waveview rendering. This is, sadly, a regression from previous releases, and will slightly slow down the apparent speed of waveform drawing. However, it was causing unacceptable crashes while recording, and until we can be absolutely certain that the issue has been correctly identified and fixed, we are disabling it.
    Add a button to master bus strip to show/hide monitor section.
    Reduce width of monitor section by 25%%.
    Allow addition of plugins to monitor section.
    Fix monitor section state restore (per-channel dim, mute etc.).
    Prefill snapshot dialog name field with current snapshot name .
    Use correct position when finishing tempo and meter marker drags.
    Fix for inoperative keyboard modifiers after auto-scrolling.
    Add more items/links to the Help menu.
    Add confirmation dialog for overwriting existing files to most (all?) file dialogs.
    Include platform-specific common disk volumes to file selection dialogs.
    New Plugin Sidebar (Mixer Window)
    drag/drop favorite Plugins directly to a track/bus.
    allow creating plugin-presets by dragging a plugin to the sidebar.
    allow to add a plugin or preset to all selected routes (double-click).
    allow dragging plugins directly from the plugin-manager to a track/bus.
    save/restore custom order of favorite plugin list.
    manage favorites and delete presets from the sidebar’s context menu.
    MIDI
    Snap modifiers now work on MIDI Notes when the grid is disabled.
    Gray out unavailable MIDI note context menu items rather than hiding them.
    update MIDI channel buttons when their mode is changed.
    Enable horizontal scrolling in MIDI regions even when a note is selected.
    Include the "Transform..." option in the MIDI region context menu.
    Introduce "Transpose..." option in the context menu for selected notes.
    Significantly speed up some MIDI note editing operations, and their impact on session loading times.
    Make MIDI Panic message work even when seamlessly looping.
    Do not clear MIDI buffers when processing cycles are split, and make seamless MIDI looping work correctly.
    Removing shorting of inserted notes by 1 tick.
    Fix overlapping MIDI note resolution.
    Better alignment of note end times with the grid.
    Fix issues with large amounts of MIDI data caused by limits on the size of Standard MIDI File format variable-length-quantities.
    Control Surfaces
    Deep support for the Presonus Faderport device. This is fully documented in the Ardour Manual.
    Mackie Control devices saw a lot of subtle changes which will be documented in the manual in the near future. It is now possible to control input trim, sends and more from a Mackie surface.
    OSC:
    Allow use of broken apps such as TouchOSC and Lemur with Ardour's OSC support
    (These apps/devices violate the OSC specification by requiring all messages to include at least one argument. The new /ardour/pushbutton/.. OSC "namespace" can be used to provide OSC addresses for messages that always one floating point argument; messages to such addresses are ignored unless the argument is 1.0)
    Add notification of changes in transport speed or record enable status
    Add easy-to-use MIDI port selectors to the Generic MIDI settings dialog
    Add a MIDI binding map for the Yamaha KX25
    Add a MIDI binding map for the Novation Impulse 49
    Add full support for NPRN MIDI controllers, allowing their use in MIDI binding maps
    Add an explicit "Show settings" button to the Control Surfaces preferences dialog to help users who do not read.
    Ensure that when control surfaces are enabled/disabled/re-enabled, they continue to be notified about the state of the session
    Automation
    Make control point selection more consistent
    Fix display of automation data for toggled controls
    Automation recording now has undo-per-pass, not undo-per-touch
    Add undo for region gain point selection
    Fix incorrect snap when adding region gain points
    Correctly select the control point to be deleted with shift+right click
    Ctrl/Cmd-drag adds or toggles rubber band selection of automation control points
    Show verbose cursor control point values in internal edit mode
    Prevent inadvertent overwriting of automation data
    Fix mute automation playback
    Fix incorrectly positioned automation control points
    Handle pasting data from non-toggled to toggled automation tracks
    Fix crash when moving tempo markers with automation present in MIDI tracks
    General Changes/Improvements
    Disable follow-edits and auto-return when synchronized to an external positional clock source.
    Fix crash when creating subgroup busses.
    Fix some cases where a session was incorrectly marked as changed/not-changed.
    Speed up session loading by avoiding unnecessary duplication scanning of MIDNAM files.
    Reduce session close time caused by some poor programming design.
    Revert back to use mjpeg as the default video codec. Anecdotal evidence suggests that mpeg4 causes issues on some platforms.
    Fix an issue where timers for metering prevent session loading from completing (also speeds up session loading).
    Duplicate regions now uses correct position (previously was off by one sample).
    Improved handling of reserved track/bus/send names ("Master", "Click" etc).
    Allow metronome to operate while varispeeding.
    Add "Duplicate Track/Bus" functionality.
    Make it possible to rename the session root folder without any side effects.
    Provide a user-preference for pre-roll.
    When loading a session, default to the most-recently-used snapshot.
    Prevent deletion of playlists not used while a track is frozen.
    Restore last used driver and device for a given audio/MIDI I/O backend.
    Prevent concurrent peak (waveform image) file initialization.
    Prevent crash when closing a session while some audio data analysis is still underway.
    Restore functionality for measuring insert latency.
    Load/save measured insert latency with session.
    Add a mechanism to allow audio latency updates without restarting the backend.
    Avoid uninintentional, unnecessary rebuilds of peak (waveform image) files.
    Fix bug with solo/mute state when reopening a session with a soloed bus.
    Explicitly disallow looping while synced to an external positional source.
    Update available positional sync sources when audioengine is restarted.
    Prevent addition of markers within 1/100th second if transport is stopped.
    Windows
    Increase open file limit count on Windows.
    New version of Windows backend that uses the PortAudio callback API. This appears to improve functionality with some audio interfaces.
    Use a range of values for ASIO buffer sizes if the ASIO driver provides one.
    Improve ipMIDI support on Windows.
    Fix latency compensation for the Windows audio/MIDI I/O backend.
    Attempted fix for issues on Windows when running on machines that use hyper-threading.
    OS X
    Update the API used on OS X to discover AudioUnit plugins, to be compatible with (a) newer versions of OS X (b) newer plugin releases (notably Waves Audio latest versions).
    Add a horrible hack to keep the program GUI responsive even when AudioUnit plugins with broken (rapidly redrawing) GUI's/editors are visible.
    Fix display of deprecated Carbon-based GUIs for some AudioUnit plugins.
    Fix for a crash on OS X caused by changing audio device state while recording.
    Add build support for OS X El Capitan.
    Fix crash when opening invalid audio/MIDI files on OS X.
    Correctly allow opening ardour via a double-click on a .ardour file inside Finder on OS X.
    Fix display of AudioUnit factory presets, so that they are shown even when there are no user presets.
    Re-add AudioUnit cache/blacklist management.
    Linux
    ALSA backend settings now include number of playback buffers (periods), possibly using different values for playback and capture.
    LinuxVST plugins: forward window resizing events to the plugin GUI.
    Infrastructure
    Add ardour4 desktop and mime type files (for use by packagers on platforms that use them)
    Add an AppData file for GNOME packagers
    Update to libsndfile 1.0.26
    Fixes to allow build system to be used on NetBSD
    Include a thread-safe version of libfftw, to fix crashes caused by some plugins
* Mon Jan 25 2016 someuniquename@gmail.com
- Fix suil package dependency
* Sun Oct 18 2015 ecsos@opensuse.org
- update to 4.4
  There are no 4.3 release
  - Substantive Changes/Features/Fixes
  - Fixed solo logic in deep ways. Most notably this prevents
    various "stuck solo" problems, but also a number of other
    issues with solo when using complex routing between tracks
    and busses.
  - Fixed loop recording (inadvertently broken for several
    releases).
  - Added support for RF64 and MBWF audio file formats. These are
    both 64 bit file formats, capable of recording impossibly
    large amounts of audio. MBWF is the 64 bit version of
    Broadcast WAV. .
  - When using either format, if recorded files are smaller than
    the RIFF (WAV) size limit, convert the header to RIFF so as
    to be compatible with normal WAV-handling software.
  - General Changes
  - "Save As" will refuse to write to an existing folder/directory.
  - "Save As" now defaults to the current session name as the
    name of the new session, making it easier to add suffixes or
    otherwise tweak the name.
  - Allow export of loop range without actually looping.
  - Improve CPU AVX support detection.
  - Fixed locating to current wallclock time for large time
    values.
  - Fixed an issue where if an audio region was locked and locked
    to video, the audio-region always stayed put and the video
    could only be moved forward.
  - Fixed various potential issues at session closing.
  - Improve error reporting from AudioEngine when trying to
    configure audio hardware.
  - Provide more details if a sessions fails to be created.
  - Improve loading speed for large sessions (1000 tracks).
  - Fixed a deadlock when removing tracks/busses and using JACK1.
  - Prevent importing files with names like "Master" or "Click"
    from causing session breakage. This also applies to attempts
    to name tracks or busses with similar names.
  - Ensure that correct audio is heard when region layering is
    changed.
  - Use a single consistent method for computing DSP load on all
    platforms, with all backends.
  - Avoid creating excessively short regions during Strip Silence
    operation.
  - Avoid possible endless loop while detecting silence.
  - Reduce chances of a bug in the OS X locale libraries from
    causing crashes.
  - Fixed duplication of multiple selected regions.
  - Correctly and consistently initialize track/bus group
    properties.
  - Fixed crash during session region cleanup.
  - Ensure identical XML in session files if the session does
    not change, thus allowing tracking state changes in a
    revision control system (e.g. git).
  - Bring Ardour's Broadcast WAVE USID value into compliance with
    EBU-R99.
  - Fixed install on systems where using su(1) changes
    directories.
  - Fixed broken onset analysis.
  - Plugins
  - Refuse to load LV2 plugins if their buffer size requirements
    cannot be satisfied.
  - Do not list LV2 plugins that cannot be used because they
    require a fixed blocksize.
  - Generally improve handling of missing plugins so that
    sessions are not damaged by the temporary unavailability of
    a plugin.
  - Fixed the position of cut/copy-and-pasted plugins.
  - Fixed AudioUnit port count, which allows loading various
    Native Instrument plugins such as Reaktor 5.
  - Added command line option to completely disable plugins.
  - Fixed handling of VST audioMasterPinConnected callback.
  - Allow loading of huge (10MB) VST plugin state.
  - GUI
    When describing keybindings below, "Primary" is used to
    describe Control on Linux and Windows, and Command on OS X
  - Fixed waveform display issues when changing waveform shape
    from rectified to normal or vice versa.
  - Added a reset option to the context menu for the shuttle
    control.
  - Allow creation of new points on a region envelope by clicking
    on the envelope line.
  - Added column titles in the list of "Recent Sessions".
  - Alter "Stop" button in the Audio/MIDI setup dialog to
    function as a "Start/Stop" button, and remove the "Apply"
    button.
  - Fixed issues where waveform display used the wrong data.
  - Cancel button for Import dialog is now a Close button.
  - Change OK button on Import dialog to "Import".
  - Correctly display plugin parameter values when dragging
    automation points/lines.
  - Fixed log-scaled automation parameter display.
  - Visually indicate regions waiting for their audio peak data
    to be generated.
  - Fixed inconsistent text sizing in the editing canvas.
  - Added avoiding GPU rendering to preferences dialog. This is
    helpful on some Linux systems with buggy video device
    drivers. See Edit > Preferences > GUI > Disable Graphics
    Hardware Acceleration.
  - Allow overriding lock-to-video when moving video or audio.
  - Fixed drawing of short cross fades.
  - Sort "Recent Sessions" by modification time.
  - Don't try to split a region when dragging.
  - Update Import dialog options when/if track selection changes.
  - Fixed marker display after a marker is removed.
  - When editing a clock display, swallow illlegal keys rather
    than passing them onto the main window where they might have
    some unintended effect.
  - Primary-Shift-click on the solo lock button now applies to
    all tracks/busses, consistent with Primary-Shift-click on
    other buttons.
  - Avoid a case where the color of selected text was the same as
    the background, making it invisible.
  - Correctly set waveform height when switching between stacked
    and overlaid view modes.
  - Make all entries in the track list context menu actually
    work.
  - Fixed incorrect setting for "Import to Region List" on first
    use of the import dialog.
  - Avoid duplicate shortcut folders in file browsers.
  - Windows
  - Drop the use of C++ fstreams to reduce issues with non-Latin
    characters in filenames on Windows.
  - Option to install without WASAPI support, which helps startup
    on Windows 10.
  - Close all files before Session > Cleanup, so that it can work
    on Windows.
  - Fixed MIDI Sysex I/O on Windows.
  - Fixed issues with onset analysis on Windows.
  - Added "Refresh Devices" button to the Audio/MIDI setup dialog
    on Windows to pick up new
  - Added a "None" device to the PortAudio backend, allowing
    disabling either input or output, but not both.
  - devices or external ASIO buffer size changes.
  - Click/Metronome
  - Added an easy way to reset the click sound(s) to their
    defaults.
  - The click sounds are now normalized to -6dBFS.
  - Allow enabling/disabling of the click "emphasis" sound.
  - MIDI
  - MIDI Tracer window now shows MSB of appropriate messages.
  - Fixed a subtle bug in ordering of MIDI events that caused
    missing note-off messages.
  - Highlight notes based on mouse position on track header
    keyboard.
  - Exclude MIDI CC parameters with no data from being displayed
    when "Show Existing Automation" is chosen.
  - Fixed issues with linked (cloned) MIDI regions on different
    tracks.
  - Fixed issues with de-selecting MIDI notes.
  - Handle a missing MIDI file without crashing.
  - MIDI/Mackie Control Surfaces
  - Save/restore generic MIDI control surface "motorized"
    setting.
  - New Mackie Control device files for configurations with
    3 surfaces.
  - A substantial amount of work has been done on Mackie Control
    support. There is no simple summary that would describe all
    the changes, but suffice it to say that (1) it works much
    better (2) it is easier to get started (3) has been tested on
    an even wider range of equipment.
* Sun Sep 13 2015 ecsos@opensuse.org
- update to 4.2
  - General Changes
  - Fix region brush drag
  - Speed up removal of multiple tracks/busses
  - Speed up solo operations applied to many tracks/busses
  - Fix several bugs with reversible commands
  - Try to avoid coincident tempo/meter markers when removing
    time
  - Improve window layering relationship between editor &
    mixerbridge
  - Add keybindings for region layering (2ndary-9 (lower),
    2ndary-0 (raise)
  - Adjust some window keybindings. (2ndary-C is now the big
    clock, 2ndary-B is the meterbridge, 2ndary-V is the video
    window
  - Fix swing quantization
  - Fix pre-fader send mute-point so that input trim still works
    when mute is engaged
  - Add configuration variable for maximum shuttle speed
  - Improve size and position of panner value displays
  - Save auto loop range and more markers in session templates
  - Mark session dirty after various region property changes
  - No longer save session after adding tracks/busses
  - Fix cleanup of any temporary files after export
  - Fix looping when using loop-is-mode and seamless looping
  - Add 176.4kHz to export sample rate list
  - Fix unintentional limits on track name length
  - Disk buffering is now defined by presets, with 3 possible
    settings as well as custom
  - When using loop-is-mode, enabling recording cancels loop
  - Attempt to reconnect LTC ports after a backend change or
    reset
  - Catch attempt to save a session with its current name as the
    new name
  - Fix flickering of certain popup windows
  - Indicate port-connections of non-track type on the mixer
    strip output button.
    (Previously a MIDI track with synth showed "—" for the output
    even if the audio output ports were connected, because only
    MIDI connections were displayed on the button).
  - Avoid crashing when cleanup unused sources
  - Fix various issues when deleting midi region during step-edit
  - Stationary playhead implies follow playhead, so make it so.
  - improve performance and reduce visual jitter when using
    stationary playhead
  - Add new configuration parameter for the default meter type to
    use with new tracks/busses
  - Add context menu to hide/show Midi-tracks — fixes #6430
  - Use “1” as the small-step size when incrementing/decrementing
    integer controls/parameters
  - Use power of 2 log-scale for logarithmic controls/parameters.
  - Remove insanely fast meter fall-off (this gave an inaccurate
    view of meter levels)
  - Fix solo isolate implementation to handle more complex
    routing pathways
  - Remove “Refresh” button in Plugin manager;
    use Preferences > Plugins
  - Fix auditioning on systems with larger disk read chunk sizes.
  - Do not crash if taglib cannot open a file
  - Fix state restoration in Audio/MIDI setup
  - Fix auditioning of audio at very different sample rates
  - Fix loss of variable amounts of final audio when importing
    from files with different sample rate than Ardour is using.
  - Plugins
  - For AU and VST plugins, differentiate between "scanning" for
    plugins (which checks that known plugins are still
    installed), and "discovery" (which potentially finds new
    plugins on the computer).
  - Offer to discover (all) plugins at first start
  - Fix LV2 freewheeling support
  - Correctly inform LV2 plugins of entire possible block size
    range (fixes some LV2 plugins which rely on this being
    correct)
  - Fix audio buffering for VST plugins (fixes lack of output or
    phased output from a variety of VST plugins)
  - With AU plugins, ensure that the plugin settings are used
    during plugin signal processing analysis
  - For AU plugins, when given a choice of picking any channel
    output count, choose stereo (not the master bus output count)
  - VST cache is now per user and per architecture (no longer
    system-wide) — this allows parallel installs of 32 &
    64bit ardour
  - By some unexplained magic, various AU plugins now load
    without crashing (notably several from Native Instruments
    such as Kontakt)
  - Add optional verbose option for VST plugin scanning
  - Automation Editing
  - Add undo/redo for touch mode and write mode
  - Selection and undo/redo behaviour when choosing control
    points
  - Display selected control points in region gain lines
  - Display selected points in internal edit mode
  - Allow dragging of region gain lines in internal edit mode
  - Make automation line / gain line cursors consistent.
  - Clicking an automation track line without a move adds a point
    on the line.
  - Fix line drag crash
  - Video
  - Possible fix for stack overflow when parsing video info
  - Fix ability to connect to Harvid on systems lacking
    "localhost" (even though this is specified as part of IPv4
    and IPv6). Examples: Chromebooks and some OS X systems.
  - Fix video-metadata for Windows.
  - Add in MXF file as a supported video format
  - Allow to select video-files regardless of file ext.
  - MIDI/Mackie Control Surfaces
  - Move learned midi binding reload after midi map load
    (fixes #6405)
  - Add a midimap for using a WiiMote via midikb.
  - Fixed generic MIDI program change event size to two bytes
    (fixes #6426)
  - Fixed pitchbend use in toggle mode so that it switches on/off
    at half way (fixes #6424)
  - Allow any one midi event to control only one thing.
  - Make program change message turn toggle controls on/off, and
    set other controls to 1.
  - Add support for 4 common types of encoders. Encoders are
    devices which use MIDI messages to send incremental rather
    than absolute position.
  - Make Mackie Control MasterPosition match MIDI port number.
* Thu Jun 25 2015 ecsos@opensuse.org
- update to 4.1
  - New Functionality
  - Input Gain Control
  - Playback- or Capture-only device support for ALSA & Coreaudio
  - Save As
  - Windows assembler metering support.
  - Click-free changes to processor order and meter position
  - User Interface Changes
  - Waveform rendering
  - Stationary playhead option
  - Layering: later is higher
  - hi-DPI support, part one
  - hi-DPI support, part two
  - Relative snap
  - X-run counter in status bar
  - Plugin parameter reset button
  - Allow deletion of MIDI Program Changes using the Delete key
  - Peak meters now have sample-accurate fall-off, no visual
    jitter
  - Automation-lane log-scale parameter support
  - New 0dBFS peak meter
  - Tap tempo
  - Remove time
  - Fixes
  - No more x-runs & noise on session-open/close
  - Fix stuck midi notes during save/auto-save
  - Fix stuck midi notes if loop-range is present
  - Various MCP improvements & tweaks
  - Properly display JACK buffersize
  - Fix importing old A2/A3 automation
  - Fix Non Session Manager support
  - VST plugins are now searched for using a case insensitive
    comparison of their filename extension
  - Relax gain/fader LPF to 25Hz (was 10Hz)
  - Fix monitor-section polarity invert
  - Fix crash when switching backends.
* Sun Apr 19 2015 ecsos@opensuse.org
- initial version 4.0
* Mon Aug 13 2012 reddwarf@opensuse.org
- Require the moderns lv2 and lilv instead of the olds lv2core
  and slv2
* Sun Jul  8 2012 lists.nico.k@googlemail.com
- updated to 2.8.13
  * Build Changes
  - Fixed build for VST support
  - Switch to new LV2 stack
  * Bug Fixes
  - Fix various crashes during session open
  - Installer works correctly when run as root
  - Fix nasty off by one error that put the end of an end-trimmed
    region one sample beyond where it should be. this would lead
    to the creation of 1 sample xfades where there should be none,
    if another region was aligned to the same point that the
    region had been nomimally trimmed to
  - Fix modifier definitions to work with newer GTK versions
  - Fix direction of zoom wheel in timebar rulers
  - Fix crash when deleting some LV2 plugins that have had a GUI
    on-screen
  - Fix click latency correction
  - Fix translation of sample rate expressed as kHz
  - Fix/workaround bug in GTK that prevents bindings from working
  - Fix non-functioning use of arrow keys in keybindings
  - Fix bug capable of causing significant "wierdness" when
    evaluating a curve in a position before the first point of the
    curve (this bug has existed in Ardour since revision 17, which
    is nearly 13,000 revisions in the past!)
  - Fixing issues with opening a browser when using the bundle.
    Use xdg-open instead of glib functions
  - Spelling fixes from Debian
  - Fix typo in region fade key bindings
  * Improvements
  - Switch to FFADO as the default firewire backend for JACK.
  - Add 176.4kHz rate to audio engine dialog.
  - Save/goto view bindings are now Shift-Fn to save, Fn to goto
    (Fn is F1, F2, etc).
  - Increase the click pool size.
  - Change reset of the click/metronome to improve behaviour when
    locating and looping.
  - Display modifier names in keybinding editor using real key
    logos (e.g. the "cauliflower" symbol for Command on OS X).
  - Make sure loop markers are shown when loop is initiated.
  - Fix odd behaviour of code used to determine if the mouse
    pointer is inside the track canvas.
  - Speed up session close by not redrawing stuff as each
    track/bus is destroyed.
  - Allow Separate to work on a range selection.
  - Crop no longer works on all tracks if no tracks are selected.
  - Improve sensitivity of some menu items based on the currently
    selected edit point.
  - Remove (sub)menu items from keybinding window.
  - Improve ruler text space above baseline.
  - Clarify what the "precise" button does in the timefx dialog by
    using a better label.
  - Various tweaks to Freesound UI.
  - Apply automation when bouncing with automation in Touch mode,
    not just Play mode.
  - Don't distort crossfades when changing their length substantially.
  - Disallow colons in snapshot names.
  - Add COMPOSER to TOC/CUE files.
  - Improved interaction with Freesound.org (backported from Mixbus
    and Ardour3).  positioned the menu bar on a non-left-most screen).
* Wed Mar  7 2012 prusnak@opensuse.org
- updated to 2.8.12
- spec cleanup
* Sun Jan 16 2011 davejplater@gmail.com
- Enabled LV2 support for 11.3 upwards.
* Fri Sep 24 2010 davejplater@gmail.com
-  Fix factory build with ardour-2.8.11-gdkinc.patch
* Fri Sep 24 2010 davejplater@gmail.com
- Update to version 2.8.11
- Upstream change :
  * Do not prevent transport operations after an export
  (and potentially at other times)
* Sun Jun 20 2010 davejplater@gmail.com
- Update to version 2.8.10
- Many new features and bugfixes since version 2.8.
- See /usr/share/doc/packages/ardour/ChangeLog for details.
* Wed Jun  3 2009 tiwai@suse.de
- updated to version 2.8:
  * mostly bugfix version, with a few new features including
    track/bus templates.  See http://ardour.org/node/2555
- fix build with soundtouch-1.4
- fix build with gcc 4.4.
* Thu Mar  5 2009 ro@suse.de
- ignore return code from po->pl renaming
* Mon Jan 19 2009 tiwai@suse.de
- updated to version 2.7.1:
  * Some new features and small fixes for annoying bugs, see
    http://ardour.org/node/2251
* Tue Nov 25 2008 tiwai@suse.de
- updated to version 2.7:
  new features and fixes: http://ardour.org/node/2209
- fix pl_PL locale path
* Mon Oct 27 2008 tiwai@suse.de
- updated to version 2.6.1:
  new features and fixes: http://ardour.org/node/2133
- regenerated python fix patch
* Wed Oct  1 2008 tiwai@suse.de
- fix build with python-2.6.
* Wed Jul 16 2008 tiwai@suse.de
- version up to 2.5:
  many new features and fixes, see http://ardour.org/node/1920
- requires aubio library
- fixed build error with the recent glibmm2 conflct with netdb.h
* Mon May 19 2008 ro@suse.de
- move check for boost before flac check to build
  with current scons
* Fri Apr 25 2008 tiwai@suse.de
- fix build with recent scons.
* Thu Apr 17 2008 tiwai@suse.de
- updated to version 2.4.1:
  * bug-fixes release: http://ardour.org/node/1683
- updated to version 2.4:
  * http://ardour.org/node/1660
* Wed Feb 13 2008 tiwai@suse.de
- updated to version 2.3.1:
  * new features: audio analysis framework, rhythm ferret,
    tab-to-transient, etc
  * improvements: outlined waveforms, a real splash screen,
    keybinding, font size changes throughout, show loop & punch
    locations properly in Locations dialog, etc.
  * lots of bug fixes
* Thu Jan 31 2008 tiwai@suse.de
- updated to version 2.2:
  * Several significant new features, lots of bugfixes
  * Improved editing model
  * Uses Rubber Band library for timestretching
* Mon Nov 19 2007 tiwai@suse.de
- fix build withg gcc 4.3
- fix misc compile warnings
* Wed Oct 10 2007 tiwai@suse.de
- VUL-0: HEAP-based buffer overflow in libsndfile (#326070,
  CVE-2007-4974)
- updated to version 2.1:
  * new import dialog
  * new JACK control dialog
  * mouse scrubbing
  * other lots of improvements/fixes, see
    http://ardour.org/node/1267
* Mon Aug  6 2007 tiwai@suse.de
- updated to version 2.0.5:
  * code builds on OS X and older Linux systems
  * font sizes parametized
  * crash revealed by GTK+ 2.11 fixed
* Thu Aug  2 2007 tiwai@suse.de
- updated to version 2.0.4:
  * protect ardour from sessions with errant capture sources
    stored in the pending session state.
  * add Theme Manager, including new "light" theme
  * add delta-cursor option from trunk
  * massively increase automation resolution
  * support for 16 bit native file format
  * stop audio clocks from vanishing when turned off
  * plugin selection dialog now has filtering by name, type,
    author and more
  * permit GUI user-driven add/remove of MIDI ports
  * fix for radio grouping of subframes menu options
  * fix crossfade editor-induced crashing
  * safeguard against false disk underruns when punching in
  * correctly save user-modified keybindings to
    ~/.ardour2/ardour.bindings
  * fixes for building against GTK-OSX
  * lots and lots of work to the Mackie Control surface support
* Mon Jul  9 2007 tiwai@suse.de
- fix libpath for non-x86_64 architectures
* Wed Jul  4 2007 tiwai@suse.de
- fix the installation path of powermate surface plugin
* Tue Jul  3 2007 tiwai@suse.de
- updated to version 2.0.3:
  * alternate file name filters for the soundfile browser
  * switch monitoring default to external
  * add declicking xfades when looping
  * new denormal handling options
  * Added/improved the ability to record while the transport is
    looping
  * added basic support for the Griffin Powermate "big knob+button"
    controller
  * correct middle button bindings on redirect names
  * fix use of .ardour rather than .ardour2 for VST presets
  * correct problems with redirect/insert dialogs being invisible
  * correctly manage video sync state
  * allow L and R as possible audio file suffixes
  * allow middle-click pasting in several dialogs
  * fix diskstream deletion crash after track removal
  * fix crashes caused by clicking in region list when there is no
    associated region for that line
  * better default buttons+icons for crossfade editor
  * move clock modes from submenu to top level
  * stop undo/redo from duplicating plugins and more
  * fix audio clock keypress/release handling
  * fix most problems with dragging close to 2^32-1 samples
  * crossfade editor usability improvements
  * fix for crash on ctrl-middle click in regions
  * fixed the stuttering/stuck problem when looping with JACK sync
  * fixed gui bug that prevented record-disable when latch record
    option is on
  * fixed issue where it would rec-enable unnecessarily when
    passing through the punch-out point
  * fixed corner case in diskstream record length
- fix build with gcc4.2 on i386
* Thu Jun 21 2007 sbrabec@suse.cz
- Build with system libraries as much as possible.
- Build with jack, flac and sqlite support.
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Thu May 10 2007 tiwai@suse.de
- revive lost buildrequires fix for libraptor-devel.
* Thu May 10 2007 tiwai@suse.de
- updated to version 2.0.2:
  * major version up, now using GTK2
* Tue Apr 17 2007 tiwai@suse.de
- fix buildrequires ladspa -> ladspa-devel
* Thu Oct 12 2006 tiwai@suse.de
- updated to 0.99.3:
  * includes gcc fixes
- rename most locales to names without land suffix.
* Thu Feb 23 2006 tiwai@suse.de
- added GTK to Categories
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 tiwai@suse.de
- fixed the build with the latest gcc.
  added -fno-strict-aliasing.
* Fri Oct 21 2005 tiwai@suse.de
- fix for gcc-4.1.
* Wed Oct 19 2005 tiwai@suse.de
- updated to version 0.99.
* Wed Oct  5 2005 tiwai@suse.de
- added flac and flac-devel to neededforbuild (required by the new
  libsndfile).
* Tue Oct  4 2005 tiwai@suse.de
- Remove LD_LIBRARY_PATH overwrite in ksi (#118188)
* Wed Apr 20 2005 pth@suse.de
- Modify code so that gcc sees a return in all cases.
* Wed Apr 20 2005 pth@suse.de
- Fix code gcc4 rejects.
- Drop libsigc++ and gtkmm from nfb as ardour uses its own copy.
* Thu Apr  7 2005 pth@suse.de
- Updated to version 0.9beta28.
- Don't use -fmove-all-movables as it's not supported by gcc >= 4
- Change configuration files so that autogen.sh can use autoreconf
* Tue Feb  8 2005 tiwai@suse.de
- updated to version 0.9beta25.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.9beta24.
* Mon Oct 18 2004 ro@suse.de
- fixed build with current glibc includes
* Tue Aug 31 2004 tiwai@suse.de
- updated to version 0.9beta19.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.9beta18.4.
* Sat Mar 27 2004 tiwai@suse.de
- fixed the default fonts (bug #36864).
- added ladspa to Requires.
* Fri Mar  5 2004 tiwai@suse.de
- updated to version 0.9beta11.2.
- fixed type-punning warnings.
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 0.9beta10.2.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 0.9beta10.
* Thu Jan 29 2004 ro@suse.de
- undef bool after including ncurses.h
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 0.9beta8.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon
* Thu Sep 11 2003 tiwai@suse.de
- fixed the strange color problem on KDE and geramik.
* Mon Sep  1 2003 adrian@suse.de
- fix double entries
* Thu Aug 28 2003 tiwai@suse.de
- fixed the build with the recent JACK.
* Thu Aug 21 2003 tiwai@suse.de
- added desktop file.
* Fri Aug 15 2003 tiwai@suse.de
- updated to 0.9beta3.
* Thu Jul  3 2003 tiwai@suse.de
- build with 0.9beta2.
* Wed Apr  2 2003 tiwai@suse.de
- updated to cvs 2003.04.02.
  disabled ksi temporarily.
* Mon Jan 27 2003 tiwai@suse.de
- fixed for gcc3.3.
* Mon Jan 20 2003 tiwai@suse.de
- updated to version cvs 2003.01.20.
  added libsamplerate and -devel to neededforbuild.
- renamed patches to avoid file-name conflictions.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Mon Sep 30 2002 sf@suse.de
- added patch for libs/ardour/Makefile.am to get the libs installed
  in /usr/lib64/ardour on bilib archs.
  (they weren't included in the rpm.)
* Thu Aug 29 2002 tiwai@suse.de
- fixed to link with libsndfile-1.0.0, extracted from cvs.
  libsndfile is linked dynamically again now.
- fixed selections, synced with cvs 2002.08.28.
* Fri Aug 16 2002 tiwai@suse.de
- updated to the cvs version 2002.08.16.
* Wed Aug  7 2002 tiwai@suse.de
- updated to the version, cvs 2002.08.06.
- including libsndfile-0.0.28 to be linked statically with ardour,
  due to the change of its API on ver.1.0rc.
- fixed for gcc3.1.
- fixed for ia64/x86-64.
- workaround: invokes autoconf & co. in ardour if ltmain.sh was
  not installed.
- removed ardour.sh.
* Tue Apr 16 2002 tiwai@suse.de
- fixed compile on i386 and axp.  the patches were swapped.
- enabled ksi again.
* Mon Apr 15 2002 tiwai@suse.de
- updated to the cvs 2002.04.15.
  built with the jack package.
- fixes for gcc-3.1.
* Sun Feb 10 2002 ro@suse.de
- new option for bz2 tar is "j"
* Tue Jan 22 2002 tiwai@suse.de
- updated to cvs 2002.01.22.
  bugfixes for edit window, presets mode and ksi.
* Tue Jan 15 2002 tiwai@suse.de
- fixed compile on gcc-3.
* Wed Jan  9 2002 tiwai@suse.de
- updated to cvs 2002.01.09.
* Thu Jan  3 2002 schwab@suse.de
- Fix missing declarations and conflicting types.
- Add atomic functions for ia64.
* Wed Jan  2 2002 tiwai@suse.de
- updated to cvs 2002.01.02.
- merged gtk-- into ardour/libs.
  now built with private sigc++ and gtk--.
* Fri Dec 14 2001 tiwai@suse.de
- updated to cvs 2001.12.14.
- moved gtk ardour from /usr/bin to /usr/X11R6/bin.
- added start-up script over ardour.
  at the first time, it copies the default configuration and
  creates ~/ardour-session directory.
* Wed Dec 12 2001 tiwai@suse.de
- updated to cvs 2001.12.12.
  - remove declick curves from Regions
  - correct, test, fix, extend XFade curves for Regions
  - don't build missing peakfiles unless told to
  - add actual functionality to RegionEditor
    vis-a-vis Region fade curves
* Mon Dec 10 2001 tiwai@suse.de
- updated to cvs 2001.12.10.
* Tue Dec  4 2001 tiwai@suse.de
- updated to cvs 2001.12.04.
* Mon Dec  3 2001 tiwai@suse.de
- built from CVS 2001.11.27.
